// @author      Kelvin Hui
// @see       	it-blogs.com
// @since     	01-Mar-2016

var express 			= require('express');
var router 				= express.Router();
var db 					= require('../../config/db');
var Customer			= require('../models/customer');

/**
 * Listing all existing records
 */
router.get('/', function(req, res) {
	Customer.list( function(rows){
		res.render('customer/list', { title: 'customer', msgType: '', msg: '', data: rows });
	});
});

/**
 * New form
 */
router.get('/new', function(req, res) {
	var customer = new Customer(0, '', '', '', '', 0, '', '', '');
	res.render('customer/new', { title: 'New Customer', msgType: '', msg: '', customer: customer});
})

/**
 * Save new
 */
router.post('/new', function(req, res) {
	var customer = new Customer(0, req.body.firstname, req.body.lastname, req.body.telephone, req.body.email, 
		req.body.age, req.body.gender, req.body.username, req.body.password);
	Customer.saveNew( customer, function(id,results){
		customer.id = id;
		var message = '';
		var msgType = '';
		if(results) {
			message = 'Save new successfully';
			msgType = 'success';
			res.render('customer/update', { title: 'Save New', msgType: msgType, msg: message, customer: customer});
		} else {
			message = 'Failed to save new record';
			msgType = 'danger';
			res.render('customer/new', { title: 'New Customer', msgType: msgType, msg: message, customer: customer});
		}		
	});	
})
 
/**
 * Update form
 */ 
router.get('/update/:id', function(req, res) {
	Customer.findByID( req.params.id, function(rows){
		if(rows.length){
			var customer = rows[0];
			res.render('customer/update', { title: 'Update Customer', msgType: '', msg: '', customer: customer});
		} else {
			Customer.list( function(rows){
				res.render('customer/list', { title: 'customer', msgType: '', msg: '', data: rows });
			});
		}
	});
})

/**
 * Save update
 */
router.post('/update/:id', function(req, res) {
	var customer = new Customer(req.params.id, req.body.firstname, req.body.lastname, req.body.telephone, req.body.email, 
		req.body.age, req.body.gender, req.body.username, req.body.password);
	Customer.update( customer, function(results){
		var message = '';
		var msgType = '';
		if(results) {
			message = 'Update successfully';
			msgType = 'success';			
		} else {
			message = 'Failed to update record';
			msgType = 'danger';
		}	
		res.render('customer/update', { title: 'Save New', msgType: msgType, msg: message, customer: customer});		
	});	
})
 
/**
 * Delete by ID
 */ 
router.get('/delete/:id', function(req, res) {
	Customer.deleteByID( req.params.id, function(results){
		var message = '';
		var msgType = '';
		if(results) {
			message = 'Delete successfully';
			msgType = 'success';
		} else {
			message = 'Failed to delete record';
			msgType = 'danger';
		}
		Customer.list( function(rows){
			res.render('customer/list', { title: 'customer', msgType: msgType, msg: message, data: rows });
		});
	});
})

module.exports = router