// @author      Kelvin Hui
// @see       	it-blogs.com
// @since     	01-Mar-2016

var express 			= require('express');
var router 				= express.Router();
var db 					= require('../../config/db');
var Product				= require('../models/product');

/**
 * Listing all existing records
 */
router.get('/', function(req, res) {
	Product.list( function(rows){
		res.render('product/list', { title: 'product', msgType: '', msg: '', data: rows });
	});
});

/**
 * New form
 */
router.get('/new', function(req, res) {
	var product = new Product(0, '', '', '', '', '', 0, 0, 0);
	res.render('product/new', { title: 'New Product', msgType: '', msg: '', product: product});
})

/**
 * Save new
 */
router.post('/new', function(req, res) {
	var product = new Product(0, req.body.name, req.body.details, req.body.price, req.body.status);
	Product.saveNew( product, function(id,results){
		product.id = id;
		var message = '';
		var msgType = '';
		if(results) {
			message = 'Save new successfully';
			msgType = 'success';
			res.render('product/update', { title: 'Save New', msgType: msgType, msg: message, product: product});
		} else {
			message = 'Failed to save new record';
			msgType = 'danger';
			res.render('product/new', { title: 'New Product', msgType: msgType, msg: message, product: product});
		}		
	});	
})
 
/**
 * Update form
 */ 
router.get('/update/:id', function(req, res) {
	Product.findByID( req.params.id, function(rows){
		if(rows.length){
			var product = rows[0];
			res.render('product/update', { title: 'Update Product', msgType: '', msg: '', product: product});
		} else {
			Product.list( function(rows){
				res.render('product/list', { title: 'product', msgType: '', msg: '', data: rows });
			});
		}
	});
})

/**
 * Save update
 */
router.post('/update/:id', function(req, res) {
	var product = new Product(req.params.id, req.body.name, req.body.details, req.body.price, req.body.status);
	Product.update( product, function(results){
		var message = '';
		var msgType = '';
		if(results) {
			message = 'Update successfully';
			msgType = 'success';			
		} else {
			message = 'Failed to update record';
			msgType = 'danger';
		}	
		res.render('product/update', { title: 'Save New', msgType: msgType, msg: message, product: product});		
	});	
})
 
/**
 * Delete by ID
 */ 
router.get('/delete/:id', function(req, res) {
	Product.deleteByID( req.params.id, function(results){
		var message = '';
		var msgType = '';
		if(results) {
			message = 'Delete successfully';
			msgType = 'success';
		} else {
			message = 'Failed to delete record';
			msgType = 'danger';
		}
		Product.list( function(rows){
			res.render('product/list', { title: 'product', msgType: msgType, msg: message, data: rows });
		});
	});
})

module.exports = router