// @author      Kelvin Hui
// @see       	it-blogs.com
// @since     	01-Mar-2016

var express 			= require('express');
var router 				= express.Router();
var db 					= require('../../config/db');
var Shop				= require('../models/shop');

/**
 * Listing all existing records
 */
router.get('/', function(req, res) {
	Shop.list( function(rows){
		res.render('shop/list', { title: 'shop', msgType: '', msg: '', data: rows });
	});
});

/**
 * New form
 */
router.get('/new', function(req, res) {
	var shop = new Shop(0, '', '', '', '', '', 0, 0, 0);
	res.render('shop/new', { title: 'New Shop', msgType: '', msg: '', shop: shop});
})

/**
 * Save new
 */
router.post('/new', function(req, res) {
	var shop = new Shop(0, req.body.name, req.body.telephone, req.body.fax, req.body.email, 
		req.body.address, req.body.map_latitude, req.body.map_longitude, req.body.status);
	Shop.saveNew( shop, function(id,results){
		shop.id = id;
		var message = '';
		var msgType = '';
		if(results) {
			message = 'Save new successfully';
			msgType = 'success';
			res.render('shop/update', { title: 'Save New', msgType: msgType, msg: message, shop: shop});
		} else {
			message = 'Failed to save new record';
			msgType = 'danger';
			res.render('shop/new', { title: 'New Shop', msgType: msgType, msg: message, shop: shop});
		}		
	});	
})
 
/**
 * Update form
 */ 
router.get('/update/:id', function(req, res) {
	Shop.findByID( req.params.id, function(rows){
		if(rows.length){
			var shop = rows[0];
			res.render('shop/update', { title: 'Update Shop', msgType: '', msg: '', shop: shop});
		} else {
			Shop.list( function(rows){
				res.render('shop/list', { title: 'shop', msgType: '', msg: '', data: rows });
			});
		}
	});
})

/**
 * Save update
 */
router.post('/update/:id', function(req, res) {
	var shop = new Shop(req.params.id, req.body.name, req.body.telephone, req.body.fax, req.body.email, 
		req.body.address, req.body.map_latitude, req.body.map_longitude, req.body.status);
	Shop.update( shop, function(results){
		var message = '';
		var msgType = '';
		if(results) {
			message = 'Update successfully';
			msgType = 'success';			
		} else {
			message = 'Failed to update record';
			msgType = 'danger';
		}	
		res.render('shop/update', { title: 'Save New', msgType: msgType, msg: message, shop: shop});		
	});	
})
 
/**
 * Delete by ID
 */ 
router.get('/delete/:id', function(req, res) {
	Shop.deleteByID( req.params.id, function(results){
		var message = '';
		var msgType = '';
		if(results) {
			message = 'Delete successfully';
			msgType = 'success';
		} else {
			message = 'Failed to delete record';
			msgType = 'danger';
		}
		Shop.list( function(rows){
			res.render('shop/list', { title: 'shop', msgType: msgType, msg: message, data: rows });
		});
	});
})

module.exports = router